hash

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package hash provides request hashing implementations for idempotency validation.

Request hashers are used to compute a hash of incoming requests to detect if two requests with the same idempotency key have different content.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BodyHasher

func BodyHasher() idempotency.RequestHasher

BodyHasher creates a request hasher that hashes the request body

func FullHasher

func FullHasher() idempotency.RequestHasher

FullHasher creates a request hasher that hashes method + path + body

Types

This section is empty.

Jump to